@@ -41,6 +41,11 @@ class TransactionsCommandsMixin:
     def watch(self, key, *keys):
         """Watch the given keys to determine execution of the MULTI/EXEC block.
         """
+        # FIXME: we can send watch through one connection and then issue
+        #   'multi/exec' command through other.
+        # Possible fix:
+        #   "Remember" a connection that was used for 'watch' command
+        #   and then send 'multi / exec / discard' through it.
         fut = self._pool_or_conn.execute(b'WATCH', key, *keys)
         return wait_ok(fut)
 
@@ -197,15 +202,16 @@ class Pipeline:
         return results
 
     def _send_pipeline(self, conn):
-        for fut, cmd, args, kw in self._pipeline:
-            try:
-                result_fut = conn.execute(cmd, *args, **kw)
-                result_fut.add_done_callback(
-                    functools.partial(self._check_result, waiter=fut))
-            except Exception as exc:
-                fut.set_exception(exc)
-            else:
-                yield result_fut
+        with conn._buffered():
+            for fut, cmd, args, kw in self._pipeline:
+                try:
+                    result_fut = conn.execute(cmd, *args, **kw)
+                    result_fut.add_done_callback(
+                        functools.partial(self._check_result, waiter=fut))
+                except Exception as exc:
+                    fut.set_exception(exc)
+                else:
+                    yield result_fut
 
     def _check_result(self, fut, waiter):
         if fut.cancelled():
@@ -255,9 +261,10 @@ class MultiExec(Pipeline):
 
     async def _do_execute(self, conn, *, return_exceptions=False):
         self._waiters = waiters = []
-        multi = conn.execute('MULTI')
-        coros = list(self._send_pipeline(conn))
-        exec_ = conn.execute('EXEC')
+        with conn._buffered():
+            multi = conn.execute('MULTI')
+            coros = list(self._send_pipeline(conn))
+            exec_ = conn.execute('EXEC')
         gather = asyncio.gather(multi, *coros, loop=self._loop,
                                 return_exceptions=True)
         last_error = None
